@@ -45,11 +45,11 @@
 #include <sys/ioctl.h>
 #include <sys/inotify.h>
 #include <sys/utsname.h>
+#include <sys/sysmacros.h>
 
 #include "udev.h"
 #include "udev-util.h"
 #include "def.h"
-#include "cgroup-util.h"
 #include "dev-setup.h"
 #include "fileio.h"
 #include "hashmap.h"
@@ -74,7 +74,6 @@ static usec_t arg_event_timeout_warn_usec = 180 * USEC_PER_SEC / 3;
 static sigset_t sigmask_orig;
 static UDEV_LIST(event_list);
 Hashmap *workers;
-static char *udev_cgroup;
 static struct udev_list properties_list;
 static bool udev_exit;
 
@@ -585,7 +584,7 @@ static bool is_devpath_busy(struct event *event) {
         return false;
 }
 
-static void event_queue_start(struct udev *udev) {
+static void event_queue_start(struct udev *udev __attribute__((unused))) {
         struct udev_list_node *loop;
 
         udev_list_node_foreach(loop, &event_list) {
@@ -602,7 +601,7 @@ static void event_queue_start(struct udev *udev) {
         }
 }
 
-static void event_queue_cleanup(struct udev *udev, enum event_state match_type) {
+static void event_queue_cleanup(struct udev *udev __attribute__((unused)), enum event_state match_type) {
         struct udev_list_node *loop, *tmp;
 
         udev_list_node_foreach_safe(loop, tmp, &event_list) {
@@ -921,7 +920,7 @@ static int handle_inotify(struct udev *udev) {
         return 0;
 }
 
-static void handle_signal(struct udev *udev, int signo) {
+static void handle_signal(struct udev *udev __attribute__((unused)), int signo) {
         switch (signo) {
         case SIGINT:
         case SIGTERM:
@@ -953,10 +952,10 @@ static void handle_signal(struct udev *udev, int signo) {
                                             pid, WTERMSIG(status), strsignal(WTERMSIG(status)));
                         } else if (WIFSTOPPED(status)) {
                                 log_info("worker ["PID_FMT"] stopped", pid);
-                                continue;
+                                break;
                         } else if (WIFCONTINUED(status)) {
                                 log_info("worker ["PID_FMT"] continued", pid);
-                                continue;
+                                break;
                         } else {
                                 log_warning("worker ["PID_FMT"] exit with status 0x%04x", pid, status);
                         }
@@ -1034,13 +1033,13 @@ static void help(void) {
         printf("%s [OPTIONS...]\n\n"
                "Manages devices.\n\n"
                "  -h --help                   Print this message\n"
-               "     --version                Print version of the program\n"
-               "     --daemon                 Detach and run in the background\n"
-               "     --debug                  Enable debug output\n"
-               "     --children-max=INT       Set maximum number of workers\n"
-               "     --exec-delay=SECONDS     Seconds to wait before executing RUN=\n"
-               "     --event-timeout=SECONDS  Seconds to wait before terminating an event\n"
-               "     --resolve-names=early|late|never\n"
+               "  -V --version                Print version of the program\n"
+               "  -d --daemon                 Detach and run in the background\n"
+               "  -D --debug                  Enable debug output\n"
+               "  -c --children-max=INT       Set maximum number of workers\n"
+               "  -e --exec-delay=SECONDS     Seconds to wait before executing RUN=\n"
+               "  -t --event-timeout=SECONDS  Seconds to wait before terminating an event\n"
+               "  -N --resolve-names=early|late|never\n"
                "                              When to resolve users and groups\n"
                , program_invocation_short_name);
 }
@@ -1063,7 +1062,7 @@ static int parse_argv(int argc, char *argv[]) {
         assert(argc >= 0);
         assert(argv);
 
-        while ((c = getopt_long(argc, argv, "c:de:DtN:hV", options, NULL)) >= 0) {
+        while ((c = getopt_long(argc, argv, "c:de:Dt:N:hV", options, NULL)) >= 0) {
                 int r;
 
                 switch (c) {
@@ -1125,6 +1124,7 @@ static int parse_argv(int argc, char *argv[]) {
 int main(int argc, char *argv[]) {
         struct udev *udev;
         sigset_t mask;
+        FILE *f;
         int fd_ctrl = -1;
         int fd_netlink = -1;
         int fd_worker = -1;
@@ -1152,8 +1152,10 @@ int main(int argc, char *argv[]) {
         if (r < 0)
                 log_warning_errno(r, "failed to parse kernel command line, ignoring: %m");
 
-        if (arg_debug)
+        if (arg_debug) {
+		log_set_target(LOG_TARGET_CONSOLE);
                 log_set_max_level(LOG_DEBUG);
+	}
 
         if (getuid() != 0) {
                 r = log_error_errno(EPERM, "root privileges required");
@@ -1277,6 +1279,12 @@ int main(int argc, char *argv[]) {
 
         udev_list_node_init(&event_list);
 
+        f = fopen("/dev/kmsg", "w");
+        if (f != NULL) {
+                fprintf(f, "<30>udevd[%u]: starting eudev-" VERSION "\n", getpid());
+                fclose(f);
+        }
+
         if (!arg_debug) {
                 int fd;
 
@@ -1386,10 +1394,6 @@ int main(int argc, char *argv[]) {
                 } else if (udev_list_node_is_empty(&event_list) && hashmap_isempty(workers)) {
                         /* we are idle */
                         timeout = -1;
-
-                        /* cleanup possible left-over processes in our cgroup */
-                        if (udev_cgroup)
-                                cg_kill(SYSTEMD_CGROUP_CONTROLLER, udev_cgroup, SIGKILL, false, true, NULL);
                 } else {
                         /* kill idle or hanging workers */
                         timeout = 3 * MSEC_PER_SEC;
